<?php
use Illuminate\Support\Facades\Route;
use App\Http\Controllers\Admin\User\{ManagePasswordController, DetailsController, UserController};
use App\Http\Controllers\Auth\{AuthenticatedSessionController};
use App\Http\Controllers\Admin\{
    FaqController,
    TopicsController,
    SettingsController,
    SiteContentController,
    InfoModalController,
    CityController,
    SubTopicController,
    DiseaseController,
    WidgetController,
    ArticleController,
    TagsController,
    SpecialityController,
    ServiceController,
    LanguageController,
    MenuController,
    ContentTestController,
    PageController,
    SubscriptionManagementController,
    RightsController,
    AdminController,
    DoctorManagementController,
    FaqCategoryController,
    AdController,
    FooterMenuController,
    ArticleBadgeController,
    HealthScanController,
    AppointmentController,
    ArticleFactController,
    DrugController,
    QuestionaireController,
    
};
use App\Http\Controllers\Artist\{
    ArtworkController
};
use App\Http\Controllers\{
    NewsletterController
};
use App\Http\Controllers\TestMailController;
use App\Http\Common\Queue;



Route::middleware('auth')->prefix('admin')->group(function () {
    
    Route::get('home', [App\Http\Controllers\Admin\AdminController::class, 'dashboard'])->name('admin.home');

    Route::post('toggle-status/{id}/{val}/{table}', function(){
        return "Code to toggle status";
        // DB::table()->where('id',$id);
    })->name('toggle_status');
    Route::get('logout', [AuthenticatedSessionController::class,'destroy_get']);
    Route::get('/', function () {
        return redirect()->route('admin.home');
    });

    //--------- Right Management -----------------------------//
    Route::get('/roles-and-permission/roles',[RightsController::class,'show_roles'])->name('roles.show');
    Route::get('/roles-and-permission/roles/add',[RightsController::class,'add_role'])->name('role.add');
    Route::post('/roles-and-permission/roles/add',[RightsController::class,'create_role'])->name('role.create');
    Route::get('/roles-and-permission/roles/edit/{role}',[RightsController::class,'edit_role'])->name('roles.edit');
    Route::post('/roles-and-permission/roles/update/{role}',[RightsController::class,'update_role'])->name('role.update');

        
    //  password management
    Route::get('manage-password',[ManagePasswordController::class, 'show_update'])->name('manage-password');
    Route::post('manage-password',[ManagePasswordController::class, 'update'])->name('manage-password');
    // user management
    Route::get('user/view', [DetailsController::class, 'show_all']);
    Route::get('user/edit', [DetailsController::class, 'edit_profile'])->name('updateProfile');
    Route::post('user/edit', [DetailsController::class, 'edit_profile'])->name('updateProfile');
    Route::get('user/{id}/profile', [DetailsController::class,'show']);

    Route::get('users',[UserController::class,'view'])->name('user_management-view');
    Route::get('user/fetch',[UserController::class,'fetch'])->name('user_management-fetch');

    // settings managements
    Route::get('settings/list', [SettingsController::class, 'index'])->name('settings');
    Route::post('settings/list', [SettingsController::class, 'update'])->name('settings');

    
    // EMPLOYEE
    Route::get('admin-users',[AdminController::class,'view'])->name('admin_users-view');
    Route::get('admin-user/fetch',[AdminController::class,'fetch'])->name('admin_users-fetch');
    
    Route::get('admin-user/add',[AdminController::class,'add'])->name('admin_users-add');
    Route::post('admin-user/add',[AdminController::class,'add'])->name('admin_users-add');
    
    Route::get('admin-user/edit/{id}',[AdminController::class,'edit'])->name('admin_users-edit');
    Route::post('admin-user/edit/{id}',[AdminController::class,'edit'])->name('admin_users-edit');

    // ARTOWRK MANAGEMENT
    Route::prefix('artwork')->controller(ArtworkController::class)->name('artwork-')->group(function () {
        include('general_routes.php');
    });

    // content management
    Route::prefix('info-model')->controller(InfoModalController::class)->name('info-model-')->group(function () {
        include('general_routes.php');
    });
    
    Route::prefix('faq-category')->controller(FaqCategoryController::class)->name('faq-category-')->group(function () {
        include('general_routes.php');
    });

    Route::prefix('faq')->controller(FaqController::class)->name('faq-')->group(function () {
        include('general_routes.php');
    });

    Route::prefix('city')->controller(CityController::class)->name('city-')->group(function () {
        include('general_routes.php');
    });


    Route::prefix('site-content')->controller(ContentTestController::class)->name('site-content-')->group(function () {
        include('general_routes.php');
    });

    Route::prefix('topics')->controller(TopicsController::class)->name('topics-')->group(function () {
        Route::get('linking-page/{id}','linkWithPage')->name('linking-page');
        Route::get('get-topics-parent-by-type',  'getParentByType')->name('get-parent-by-type');
        Route::get('fetch',[TopicsController::class,'fetch'])->name('topics-fetch');
        include('general_routes.php');
    });

    Route::prefix('sub_topic')->controller(SubTopicController::class)->name('sub_topic-')->group(function () {
        include('general_routes.php');
    });

    Route::prefix('disease')->controller(DiseaseController::class)->name('disease-')->group(function () {
        Route::get('linking-page/{id}/{lang_id?}',  'linkWithPage')->name('linking-page');
        include('general_routes.php');
    });

    Route::prefix('drug')->controller(DrugController::class)->name('drug-')->group(function () {
        Route::get('linking-page/{id}/{lang_id?}',  'linkWithPage')->name('linking-page');
        include('general_routes.php');
    });

    Route::prefix('widget')->controller(WidgetController::class)->name('widget-')->group(function () {
        include('general_routes.php');
    });

    Route::prefix('article')->controller(ArticleController::class)->name('article-')->group(function () {
        Route::get('get-article-parent-by-type',  'getArticleParentByType')->name('get-parent-by-type');
        Route::get('fetch',[ArticleController::class,'fetch'])->name('article-fetch');
        Route::get('delete-widget/{reference_id}',[ArticleController::class,'deleteWidgetByReference'])->name('delete-widget');
        include('general_routes.php');
    });
    
    Route::prefix('tag')->controller(TagsController::class)->name('tag-')->group(function () {
        include('general_routes.php');
    });
        
    Route::prefix('speciality')->controller(SpecialityController::class)->name('speciality-')->group(function () {
        Route::get('fetch',[SpecialityController::class,'fetch'])->name('speciality-fetch');
        include('general_routes.php');
    });

    Route::prefix('service')->controller(ServiceController::class)->name('service-')->group(function () {
        Route::get('fetch',[ServiceController::class,'fetch'])->name('service-fetch');
        include('general_routes.php');
    });

    Route::prefix('language')->controller(LanguageController::class)->name('language-')->group(function () {
        include('general_routes.php');
    });

    Route::prefix('menu')->controller(MenuController::class)->name('menu-')->group(function () {
        Route::get('get-menu-parent-by-type',  'getParentsByType')->name('get-parent-by-type');

        Route::get('view/{lang_id}','view')->name('view');
        Route::get('fetch/{lang_id}','fetch')->name('fetch');
        
        Route::post('update-sequence/{lang_id}/','update_sequence')->name('update_sequence');
        
        Route::get('add/{lang_id}','add')->name('add');
        Route::post('add/{lang_id}','add')->name('add');
        
        Route::get('edit/{id}/{lang_id}','edit')->name('edit');
        Route::post('edit/{id}/{lang_id}','edit')->name('edit');
    });

    Route::prefix('page')->controller(PageController::class)->name('page-')->group(function () {
        Route::get('linking-page/{id}/{lang_id?}',  'linkWithPage')->name('linking-page');
        Route::get('get-page-parent-by-type',  'getPageParentByType')->name('get-parent-by-type');
        Route::get('fetch',[PageController::class,'fetch'])->name('page-fetch');
        Route::get('delete-widget/{reference_id}',[PageController::class,'deleteWidgetByReference'])->name('delete-widget');
        include('general_routes.php');
    });

    Route::prefix('subscription')->controller(SubscriptionManagementController::class)->name('subscription-')->group(function () {
        include('general_routes.php');
    });

    // Route::get('rearrange/{reference_widget_id}',[ArticleController::class,'reArrangeReferenceWidgets']);
    Route::post('move-widget',[ArticleController::class, 'repositionWidget'])->name('repositionWidget');
    Route::post('add-widget',[ArticleController::class, 'addWidget'])->name('article-addWidget');
    Route::post('page/add-widget',[PageController::class, 'addWidget'])->name('page-addWidget');
    Route::post('delete-widget',[ArticleController::class, 'deleteWidget'])->name('deleteWidget');
    
    // Doctor management Routes
    Route::prefix('doctor')->controller(DoctorManagementController::class)->name('doctor-')->group(function () {
        include('general_routes.php');

        Route::get('reviews/{doctor_id}','reviews')->name('reviews');
        
        // UPDATE SERVICES
        Route::get('services/update/{doctor_id}','updateServices')->name('update-services');
        Route::post('services/update/{doctor_id}','updateServices')->name('update-services');
        
        // UPDATE SPECIALITIES
        Route::get('specialities/update/{doctor_id}','updateSpecialities')->name('update-specialities');
        Route::post('specialities/update/{doctor_id}','updateSpecialities')->name('update-specialities');

        
        // UPDATE SPECIALITIES
        Route::get('experiences/update/{doctor_id}','updateExperiences')->name('update-experiences');
        Route::post('experiences/update/{doctor_id}','updateExperiences')->name('update-experiences');

        
        // UPDATE SPECIALITIES
        Route::get('educations/update/{doctor_id}','updateEducations')->name('update-educations');
        Route::post('educations/update/{doctor_id}','updateEducations')->name('update-educations');
    });
    
    // Doctor management Routes
    Route::prefix('ads')->controller(AdController::class)->name('ads-')->group(function () {
        include('general_routes.php');
    });

    Route::prefix('footer')->controller(FooterMenuController::class)->name('footer-')->group(function () {  
        Route::get('view/{lang_id}','view')->name('view');
        Route::get('fetch/{lang_id}','fetch')->name('fetch');
        
        Route::post('update-sequence','update_sequence')->name('update_sequence');
        
        Route::get('add/{lang_id}','add')->name('add');
        Route::post('add/{lang_id}','add')->name('add');
        
        Route::get('edit/{id}/{lang_id}','edit')->name('edit');
        Route::post('edit/{id}/{lang_id}','edit')->name('edit');
    });

    Route::prefix('article-badge')->controller(ArticleBadgeController::class)->name('article_badge-')->group(function () {
        include('general_routes.php');
    });

    Route::prefix('health-scan-management')->controller(HealthScanController::class)->name('health-scan-management-')->group(function () {
        include('general_routes.php');
    });

    Route::prefix('appointment')->controller(AppointmentController::class)->name('appointment-')->group(function () {
        Route::get('get-form/{appointment_id}','getQuestionaireForm')->name('get_questionaire_form');
        Route::post('get-form/{appointment_id}','getQuestionaireForm')->name('get_questionaire_form');
        Route::get('detail/{id}','detail')->name('detail');
        include('general_routes.php');
    });

    Route::prefix('questionaire-form')->controller(QuestionaireController::class)->name('questionaire_form-')->group(function () {
        include('general_routes.php');
    });
    
    Route::get('send-mail',[TestMailController::class, 'sendMail'])->name('sendMail');
    Route::get('send-sms',[TestMailController::class, 'sendSms'])->name('sendSms'); 
    Route::get('create-admin-notification',[TestMailController::class, 'createAdminNotification'])->name('create_admin_notification'); 
    Route::get('push-notification',[TestMailController::class, 'sendPushNotification'])->name('push_notification'); 
    
    Route::prefix('report')->controller(ReportController::class)->name('report-')->group(function () {
        Route::get('sehat-scan','SehatScanReports')->name('sehat_scan_report');
        Route::get('sehat-scan/fetch','FetchSehatScanReports')->name('sehat_scan_report-fetch');
        
    });

    Route::prefix('newsletter')->controller(NewsletterController::class)->name('newsletter-')->group(function () {
        include('general_routes.php');
    });

    Route::prefix('article-fact')->controller(ArticleFactController::class)->name('article-fact-')->group(function () {
        include('general_routes.php');
    });

});
