<?php

use Illuminate\Support\Facades\Route;
use App\Http\Controllers\Api\{
    ApiTokenController,
    UserController,
    FamilyMemberController,
    MedicalRecordController,
    ReviewController,
    ClinicController,
    SubscriptionController,
    AppointmentController,
    ArticleController,
    HealthScanController,
    PageController,
    PaymentController,
    SettingController,
    InstantConsultationController,
    ApiGeneralController,
    CronJobController,

    AddressController,

};
use App\Http\Common\{ResponseHelper};

/*
|--------------------------------------------------------------------------
| API Routes
|--------------------------------------------------------------------------
|
| Here is where you can register API routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| is assigned the "api" middleware group. Enjoy building your API!
|
*/

Route::post('/get/token', [ApiTokenController::class, 'getToken']);

// Routes for Search for Articles
Route::get('/article/search', [ArticleController::class, 'searchArticle'])->name('article-searches');

// Routes for expire subscriptions
Route::get('/cron/expire-subscription', [CronJobController::class, 'expireSubscription']);

// Routes for appointment notifications or reminder
Route::get('/cron/appointment-reminder', [CronJobController::class, 'appointmentReminder']);

// AUTH ROUTES
Route::group(['middleware' => 'api_auth'], function() {

    
    require __DIR__.'/doctor.php';

    Route::post('/social-login', [UserController::class, 'socialLogin']);
    Route::post('/login', [UserController::class, 'login']);
    Route::post('/resend-otp', [UserController::class, 'resendOtp']);
    Route::post('/verify-otp', [UserController::class, 'verifyOtp']);
    Route::get('/user', [UserController::class, 'getUser']);
    Route::post('/update-profile', [UserController::class, 'updateProfile']);
    Route::get('/logout', [UserController::class, 'logout']);
    // Route::post('/doctor/registration', [UserController::class, 'doctorRegistration']);
    // Route::post('/doctor/login', [UserController::class, 'doctorLogin']);
    // Route::post('/doctor/update', [UserController::class, 'updateDoctor']);
    // Route::get('/doctor/service/delete/{id}', [UserController::class, 'deleteService']);
    // Route::get('/doctor/education/delete/{id}', [UserController::class, 'deleteEducation']);
    // Route::post('/forgot/password', [UserController::class, 'forgotPasswordMail']);
    // Route::post('/forgot/password/otp', [UserController::class, 'forgotPassword']);
    // Route::post('/password/reset', [UserController::class, 'resetPassword']);
    // Route::post('/password/update', [UserController::class, 'updatePassword']);
    // Route::get('/appointment/dashboard', [AppointmentController::class, 'dashboard']);
    
    // Routes for Family Members
    Route::prefix('family-member')->group(function(){
        Route::post('/', [FamilyMemberController::class, 'createFamilyMember']);
        Route::post('/{familyMember}', [FamilyMemberController::class, 'updateFamilyMember'])->missing(function(){
            return ResponseHelper::returnJsonResponse(404, 'Invalid family member id.');
        });
        Route::get('/', [FamilyMemberController::class, 'getFamilyMember']);
        Route::delete('/{familyMember}', [FamilyMemberController::class, 'deleteFamilyMember'])->missing(function(){
            return ResponseHelper::returnJsonResponse(404, 'Invalid family member id.');
        });
    });
    
    // Routes for MedicalRecords
    Route::prefix('medical-record')->group(function(){
        Route::post('/', [MedicalRecordController::class, 'createMedicalRecord']);
        Route::post('/share', [MedicalRecordController::class, 'shareMedicalRecord']);
        
        Route::post('/{medicalRecord}', [MedicalRecordController::class, 'updateMedicalRecord'])->missing(function(){
            return ResponseHelper::returnJsonResponse(404, 'Invalid medical record id.');
        });
        Route::get('/', [MedicalRecordController::class, 'getMedicalRecord']);
        Route::delete('/{medicalRecord}', [MedicalRecordController::class, 'deleteMedicalRecord'])->missing(function(){
            return ResponseHelper::returnJsonResponse(404, 'Invalid medical record id.');
        });
        Route::delete('file/{medicalRecordFile}', [MedicalRecordController::class, 'deleteMedicalRecordFile'])->missing(function(){
            return ResponseHelper::returnJsonResponse(404, 'Invalid medical record file id.');
        });
    });
    
    // Routes for Reviews Routes
    Route::prefix('review')->group(function(){
        Route::post('/', [ReviewController::class, 'createReview']);
        Route::get('/{doctor}', [ReviewController::class, 'getReview'])->missing(function(){
            return ResponseHelper::returnJsonResponse(404, 'Invalid doctor id.');
        });
    });
 
    // Routes for Subscription
    Route::prefix('subscription')->group(function(){
        Route::get('/', [SubscriptionController::class, 'getPackages']);
    });
    
    // Routes for FAQ's
    Route::get('/faqs', [UserController::class, 'getFaqs']);
    
    // Routes for FAQ's
    Route::post('/newsletter', [UserController::class, 'subscribeNewsletter']);

    Route::prefix('appointment')->group(function(){
        Route::post('/', [AppointmentController::class, 'createAppointment']);
        Route::get('/{appointment}', [AppointmentController::class, 'getAppointmentDetail'])->missing(function(){
            return ResponseHelper::returnJsonResponse(404, 'Invalid Appointment ID.');
        });
        Route::post('/{appointment}', [AppointmentController::class, 'updateAppointment'])->missing(function(){
            return ResponseHelper::returnJsonResponse(404, 'Invalid Appointment ID.');
        });
        Route::get('/', [AppointmentController::class, 'getAppointments']);
        Route::get('/cancel/{appointment}', [AppointmentController::class, 'cancelAppointment'])->missing(function(){
            return ResponseHelper::returnJsonResponse(404, 'Invalid Appointment ID.');
        });
        Route::get('/download-prescription/{id}', [AppointmentController::class, 'downloadPrescription']);
    });
    
    // Route::post('/str/compose',[AppointmentController::class,'strCompose']);

    // Routes for Articles related API's
    Route::prefix('article')->group(function(){
        // Routes for Get the Next Article Details with respect to the current article tags OR related articles
        Route::get('/next-article', [ArticleController::class, 'getNextRelatedArticle']);

        // Routes for Search for Articles
        Route::get('/article/search', [ArticleController::class, 'searchArticle'])->name('article-search');
        
        // Get the article details
        Route::get('/{article}', [ArticleController::class, 'getArticles'])->missing(function(){
            return ResponseHelper::returnJsonResponse(404, 'Invalid article id.');
        });
    });

    // Routes for Diseases related API's
    Route::get('/disease', [ArticleController::class, 'getDiseases']);

    // Routes for Drugs related API's
    Route::get('/drug', [ArticleController::class, 'getDrugs']);

    // Routes for Dynamic Menu related API's
    Route::get('/menu', [ArticleController::class, 'getMenu']);

    // Routes for Medicines Listing
    Route::get('/medicine', [ArticleController::class, 'getMedicines']);

    // Routes for Dynamic Footer Listing
    Route::get('/footer', [ArticleController::class, 'getFooters']);

    // Routes for Topics Listing
    Route::get('/topics', [ArticleController::class, 'getTopics']);

    // Routes for Sub Topics Listing
    Route::get('/sub-topics', [ArticleController::class, 'getSubTopics']);

    // Routes for Cities Listing
    Route::get('/cities', [ArticleController::class, 'getCities']);

    // Routes for Prescription Elements Listing
    Route::get('/prescription-elements', [ArticleController::class, 'getPrescriptionElementListing']);

    // Routes for Clinic Listing
    Route::get('/clinics', [ArticleController::class, 'getClinics']);

    // Routes for Prescription Element Types Listing
    Route::get('/prescription-element-types', [ArticleController::class, 'getPrescriptionElementTypeListing']);

    // Routes for Universities Listing
    Route::get('/universities', [ArticleController::class, 'getUniversities']);

    // Routes for Degrees Listing
    Route::get('/degrees', [ArticleController::class, 'getDegrees']);

    // Routes for Specialities Listing
    Route::get('/specialities', [ArticleController::class, 'getSpecialities']);

    // Routes for services Listing
    Route::get('/services', [ArticleController::class, 'getServices']);
    
    // Routes for Health Scans API's
    Route::prefix('health-scan')->group(function(){
        Route::post('/', [HealthScanController::class, 'createHealthScan']);
        Route::get('/{healthScan}', [HealthScanController::class, 'getHealthScanDetails'])->missing(function(){
            return ResponseHelper::returnJsonResponse(404, 'Invalid health scan id.');
        });
        Route::get('/', [HealthScanController::class, 'listHealthScans']);
        Route::post('/check', [HealthScanController::class, 'checkLimitation']);
    });

    // Routes for Get the Page Details
    
    Route::post('/content-feedback', [PageController::class,'contentFeedback'])->name('content-feedback');
    Route::get('/page/{page}', [PageController::class, 'getPageDetails'])->missing(function(){
        return ResponseHelper::returnJsonResponse(404, 'Invalid page name.');
    });
    
    // Routes for Get the Nested Topic Details
    Route::get('/topic/{topic}/{subTopic}/{nestedTopic}', [PageController::class, 'getTopicDetails'])->missing(function(){
        return ResponseHelper::returnJsonResponse(404, 'Invalid nested topic name.');
    });
    
    // Routes for Get the Sub Topic Details
    Route::get('/topic/{topic}/{subTopic}', [PageController::class, 'getTopicDetails'])->missing(function(){
        return ResponseHelper::returnJsonResponse(404, 'Invalid sub topic name.');
    });

    // Routes for Get the Topic Details
    Route::get('/topic/{topic}', [PageController::class, 'getTopicDetails'])->missing(function(){
        return ResponseHelper::returnJsonResponse(404, 'Invalid topic name.');
    });

    // Routes for Get Privacy Policy
    Route::get('/privacy-policy', [SettingController::class, 'privacyContent']);

    // Routes for Get the Disease Details
    Route::get('/disease/{disease}', [PageController::class, 'getDiseaseDetails'])->missing(function(){
        return ResponseHelper::returnJsonResponse(404, 'Invalid disease name.');
    });

    // Routes for Get the Drug Details
    Route::get('/drug/{drug}', [PageController::class, 'getDrugDetails'])->missing(function(){
        return ResponseHelper::returnJsonResponse(404, 'Invalid drug name.');
    });

    // Routes for Get the Doctor Details by applying filters
    Route::get('/find-a-doctor', [UserController::class, 'searchDoctors']);

    // Routes for Get the Info Modal  Details
    Route::get('/info-modal/{key}', [SettingController::class, 'getInfoModalDetail']);

    // Routes for Get the Doctor Clinic Details
    Route::get('/doctor-clinic-time/{doctorClinicId}', [ClinicController::class, 'getAllTimeSlots']);

    // Routes for Like or Un-Like article
    Route::post('/review-article', [UserController::class, 'likeOrUnLike']);

    // Routes for payments for appointment or subscription packages
    Route::post('/payment', [PaymentController::class, 'makePayment']);

    // Routes for User Dashboard Details
    Route::get('/dashboard', [UserController::class, 'getDashboardDetails']);

    // Routes for Instant Consultation
    Route::get('/instant-consultation/start', [InstantConsultationController::class, 'startConsultaion']);

    // Routes for Agora Details
    Route::get('/generate-agora-link', [InstantConsultationController::class, 'generateAgoraLink']);

    // General ROUTES for getting the seeting details
    Route::get('/preferances', [ApiGeneralController::class, 'preferences']);

    // Routes for Get the specialities, services and cities with doctor counts
    Route::get('/search-doctor-by-category', [UserController::class, 'searchDoctorByCategory']);

    // Routes for Get the Header searching i.e articles, topics, diseases etc
    Route::get('/search', [UserController::class, 'headerSearch']);

    // Routes for get vitals or health scans details with hash id
    Route::get('/vitals/{id}', [HealthScanController::class, 'getHealthScanByHash']);

    // Routes for Buy subscriptions and get doctor details
    Route::get('/buy-subscription-doctor-details', [SubscriptionController::class, 'getDoctorDetails']);

    // Routes for get doctors and hospitals details
    Route::get('/widget-search-doctor', [UserController::class, 'widgetDoctorSearch']);

    // Routes for user delete
    Route::get('/delete-user', [UserController::class, 'deleteUserAccount']);


    // ADDRESS CRUD
    Route::prefix('address')->controller(AddressController::class)->group(function(){
        Route::get('/', 'getALlAddresses');
        Route::get('/{address_id}', 'getAddress');
        Route::post('/update-status/{address_id}', 'updateStatus');
        Route::post('/create', 'create');
        Route::post('/update/{address_id}', 'update');
    });
     
});